API
===

Import statement::

    import monkeybread as mb

Calculations (``calc``)
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: monkeybread.calc

.. currentmodule:: monkeybread

.. autosummary::
    :toctree: api

    calc.cell_contact
    calc.kernel_density
    calc.shortest_distances
    calc.cell_transcript_proximity

Plotting (``plot``)
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: monkeybread.plot

.. currentmodule:: monkeybread

.. autosummary::
    :toctree: api

    plot.cell_contact_embedding
    plot.cell_contact_histplot
    plot.cell_contact_heatmap
    plot.kernel_density
    plot.shortest_distances
    plot.cell_transcript_proximity
    plot.volcano_plot

Statistics (``stat``)
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: monkeybread.stat

.. currentmodule:: monkeybread

.. autosummary::
    :toctree: api

    stat.cell_contact
    stat.shortest_distances

Utilities (``util``)
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: monkeybread.util

.. currentmodule:: monkeybread

.. autosummary::
    :toctree: api

    util.randomize_positions
    util.subset_cells
    util.load_merscope
